@@ -10,15 +10,16 @@ import numpy as np
 import os
 import pandas as pd
 
-from reV.handlers.resource import Resource
 from reV.handlers.outputs import Outputs
 from reV.supply_curve.exclusions import ExclusionMaskFromDict
 from reV.supply_curve.points import (SupplyCurveExtent,
                                      AggregationSupplyCurvePoint)
-from reV.utilities.execution import SpawnProcessPool
 from reV.utilities.exceptions import (EmptySupplyCurvePointError,
                                       FileInputError)
 
+from rex.resource import Resource
+from rex.utilities.execution import SpawnProcessPool
+from rex.utilities.loggers import log_mem
 
 logger = logging.getLogger(__name__)
 
@@ -178,7 +179,7 @@ class AbstractAggregation(ABC):
 
         if gids is None:
             with SupplyCurveExtent(excl_fpath, resolution=resolution) as sc:
-                gids = np.array(range(len(sc)), dtype=np.uint32)
+                gids = sc.valid_sc_points(tm_dset)
         elif not isinstance(gids, np.ndarray):
             gids = np.array(gids)
 
@@ -277,6 +278,10 @@ class AbstractAggregation(ABC):
                 except EmptySupplyCurvePointError:
                     pass
 
+                except Exception:
+                    logger.exception('SC gid {} failed!'.format(gid))
+                    raise
+
                 else:
                     output.append(gid_out)
 
@@ -318,13 +323,13 @@ class AbstractAggregation(ABC):
         n_finished = 0
         futures = []
         output = []
-
-        with SpawnProcessPool(max_workers=max_workers) as executor:
+        loggers = [__name__, 'reV.supply_curve.points']
+        with SpawnProcessPool(max_workers=max_workers, loggers=loggers) as exe:
 
             # iterate through split executions, submitting each to worker
             for gid_set in chunks:
                 # submit executions and append to futures list
-                futures.append(executor.submit(
+                futures.append(exe.submit(
                     self.run_serial,
                     sc_point_method, self._excl_fpath, self._tm_dset,
                     excl_dict=self._excl_dict,
@@ -618,7 +623,7 @@ class Aggregation(AbstractAggregation):
         with SupplyCurveExtent(excl_fpath, resolution=resolution) as sc:
             exclusion_shape = sc.exclusions.shape
             if gids is None:
-                gids = range(len(sc))
+                gids = sc.valid_sc_points(tm_dset)
 
         # pre-extract handlers so they are not repeatedly initialized
         file_kwargs = {'excl_dict': excl_dict,
@@ -628,6 +633,7 @@ class Aggregation(AbstractAggregation):
         dsets = agg_dset + ('meta', )
         agg_out = {ds: [] for ds in dsets}
         with AggFileHandler(excl_fpath, h5_fpath, **file_kwargs) as fh:
+            n_finished = 0
             for gid in gids:
                 try:
                     gid_out = AggregationSupplyCurvePoint.run(
@@ -647,11 +653,17 @@ class Aggregation(AbstractAggregation):
                 except EmptySupplyCurvePointError:
                     logger.debug('SC gid {} is fully excluded or does not '
                                  'have any valid source data!'.format(gid))
-                    gid_out = None
+                except Exception:
+                    logger.exception('SC gid {} failed!'.format(gid))
+                    raise
                 else:
-                    if gid_out is not None:
-                        for k, v in gid_out.items():
-                            agg_out[k].append(v)
+                    n_finished += 1
+                    logger.debug('Serial aggregation: '
+                                 '{} out of {} points complete'
+                                 .format(n_finished, len(gids)))
+                    log_mem(logger)
+                    for k, v in gid_out.items():
+                        agg_out[k].append(v)
 
         return agg_out
 
@@ -690,11 +702,12 @@ class Aggregation(AbstractAggregation):
         futures = []
         dsets = self._agg_dsets + ('meta', )
         agg_out = {ds: [] for ds in dsets}
-        with SpawnProcessPool(max_workers=max_workers) as executor:
+        loggers = [__name__, 'reV.supply_curve.points']
+        with SpawnProcessPool(max_workers=max_workers, loggers=loggers) as exe:
             # iterate through split executions, submitting each to worker
             for gid_set in chunks:
                 # submit executions and append to futures list
-                futures.append(executor.submit(
+                futures.append(exe.submit(
                     self.run_serial,
                     self._excl_fpath,
                     self._h5_fpath,
