@@ -64,12 +64,23 @@ def from_config(ctx, config_file, verbose):
                 job_attrs={'hardware': 'local',
                            'fout': '{}.csv'.format(name),
                            'dirout': config.dirout})
-            ctx.invoke(main, name, config.sc_points, config.trans_table,
-                       config.fixed_charge_rate, config.sc_features,
-                       config.transmission_costs, config.sort_on,
-                       config.dirout, config.logdir,
-                       config.simple, config.line_limited,
-                       verbose)
+            ctx.invoke(main,
+                       name=name,
+                       sc_points=config.sc_points,
+                       trans_table=config.trans_table,
+                       fixed_charge_rate=config.fixed_charge_rate,
+                       sc_features=config.sc_features,
+                       transmission_costs=config.transmission_costs,
+                       sort_on=config.sort_on,
+                       wind_dirs=config.wind_dirs,
+                       n_dirs=config.n_dirs,
+                       downwind=config.downwind,
+                       max_workers=config.max_workers,
+                       out_dir=config.dirout,
+                       log_dir=config.logdir,
+                       simple=config.simple,
+                       line_limited=config.line_limited,
+                       verbose=verbose)
 
     elif config.execution_control.option in ('eagle', 'slurm'):
 
@@ -80,6 +91,10 @@ def from_config(ctx, config_file, verbose):
         ctx.obj['SC_FEATURES'] = config.sc_features
         ctx.obj['TRANSMISSION_COSTS'] = config.transmission_costs
         ctx.obj['SORT_ON'] = config.sort_on
+        ctx.obj['WIND_DIRS'] = config.wind_dirs
+        ctx.obj['N_DIRS'] = config.n_dirs
+        ctx.obj['DOWNWIND'] = config.downwind
+        ctx.obj['MAX_WORKERS'] = config.max_workers
         ctx.obj['OUT_DIR'] = config.dirout
         ctx.obj['LOG_DIR'] = config.logdir
         ctx.obj['SIMPLE'] = config.simple
@@ -118,7 +133,7 @@ def from_config(ctx, config_file, verbose):
                     'power-rose value at each cardinal direction'))
 @click.option('--n_dirs', '-dirs', type=int, default=2,
               help='Number of prominent directions to use')
-@click.option('--downwind' '-dw', is_flag=True,
+@click.option('--downwind', '-dw', is_flag=True,
               help=('Flag to remove downwind neighbors as well as upwind '
                     'neighbors'))
 @click.option('--max_workers', '-mw', type=INT, default=None,
@@ -220,9 +235,7 @@ def get_node_cmd(name, sc_points, trans_table, fixed_charge_rate, sc_features,
             '-scf {sc_features} '
             '-tc {transmission_costs} '
             '-so {sort_on} '
-            '-wd {wind_dirs} '
             '-dirs {n_dirs} '
-            '-dw {downward} '
             '-mw {max_workers} '
             '-o {out_dir} '
             '-ld {log_dir} '
@@ -235,18 +248,24 @@ def get_node_cmd(name, sc_points, trans_table, fixed_charge_rate, sc_features,
                        sc_features=SLURM.s(sc_features),
                        transmission_costs=SLURM.s(transmission_costs),
                        sort_on=SLURM.s(sort_on),
-                       wind_dirs=SLURM.s(wind_dirs),
                        n_dirs=SLURM.s(n_dirs),
-                       downwind=SLURM.s(downwind),
                        max_workers=SLURM.s(max_workers),
                        out_dir=SLURM.s(out_dir),
                        log_dir=SLURM.s(log_dir),
                        )
 
+    if wind_dirs is not None:
+        args += '-wd {wind_dirs} '.format(wind_dirs=SLURM.s(wind_dirs))
+
+    if downwind:
+        args += '-dw '
+
     if simple:
         args += '-s '
+
     if line_limited:
         args += '-ll '
+
     if verbose:
         args += '-v '
 
@@ -308,6 +327,7 @@ def slurm(ctx, alloc, memory, walltime, feature, conda_env, module,
     else:
         logger.info('Running reV Supply Curve on SLURM with '
                     'node name "{}"'.format(name))
+        logger.debug('\t{}'.format(cmd))
         slurm = SLURM(cmd, alloc=alloc, memory=memory,
                       walltime=walltime, feature=feature,
                       name=name, stdout_path=stdout_path,
