@@ -15,18 +15,19 @@ from scipy.spatial import cKDTree
 from warnings import warn
 
 from reV.handlers.exclusions import ExclusionLayers
-from reV.handlers.resource import Resource
 from reV.supply_curve.aggregation import (AbstractAggFileHandler,
                                           AbstractAggregation,
                                           Aggregation)
 from reV.supply_curve.exclusions import FrictionMask
 from reV.supply_curve.points import SupplyCurveExtent
 from reV.supply_curve.point_summary import SupplyCurvePointSummary
-from reV.utilities.execution import SpawnProcessPool
 from reV.utilities.exceptions import (EmptySupplyCurvePointError,
                                       OutputWarning, FileInputError,
                                       InputWarning, SupplyCurveInputError)
 
+from rex.resource import Resource
+from rex.utilities.execution import SpawnProcessPool
+
 logger = logging.getLogger(__name__)
 
 
@@ -89,7 +90,8 @@ class SupplyCurveAggFileHandler(AbstractAggFileHandler):
         self._friction_layer = None
         if friction_fpath is not None and friction_dset is not None:
             self._friction_layer = FrictionMask(friction_fpath, friction_dset)
-            if not all(self._friction_layer.shape == self._excl.shape):
+
+            if not np.all(self._friction_layer.shape == self._excl.shape):
                 e = ('Friction layer shape {} must match exclusions shape {}!'
                      .format(self._friction_layer.shape, self._excl.shape))
                 logger.error(e)
@@ -506,7 +508,7 @@ class SupplyCurveAggregation(AbstractAggregation):
             points = sc.points
             exclusion_shape = sc.exclusions.shape
             if gids is None:
-                gids = range(len(sc))
+                gids = sc.valid_sc_points(tm_dset)
 
         # pre-extract handlers so they are not repeatedly initialized
         file_kwargs = {'data_layers': data_layers,
@@ -526,6 +528,7 @@ class SupplyCurveAggregation(AbstractAggregation):
                                                             cf_dset,
                                                             lcoe_dset)
 
+            n_finished = 0
             for gid in gids:
                 for ri, res_bin in enumerate(inputs[1]):
                     try:
@@ -553,6 +556,10 @@ class SupplyCurveAggregation(AbstractAggregation):
                     except EmptySupplyCurvePointError:
                         pass
 
+                    except Exception:
+                        logger.exception('SC gid {} failed!'.format(gid))
+                        raise
+
                     else:
                         pointsum['sc_point_gid'] = gid
                         pointsum['sc_row_ind'] = points.loc[gid, 'row_ind']
@@ -560,6 +567,10 @@ class SupplyCurveAggregation(AbstractAggregation):
                         pointsum['res_class'] = ri
 
                         summary.append(pointsum)
+                        n_finished += 1
+                        logger.debug('Serial aggregation: '
+                                     '{} out of {} points complete'
+                                     .format(n_finished, len(gids)))
 
         return summary
 
@@ -595,13 +606,13 @@ class SupplyCurveAggregation(AbstractAggregation):
         n_finished = 0
         futures = []
         summary = []
-
-        with SpawnProcessPool(max_workers=max_workers) as executor:
+        loggers = [__name__, 'reV.supply_curve.point_summary']
+        with SpawnProcessPool(max_workers=max_workers, loggers=loggers) as exe:
 
             # iterate through split executions, submitting each to worker
             for gid_set in chunks:
                 # submit executions and append to futures list
-                futures.append(executor.submit(
+                futures.append(exe.submit(
                     self.run_serial,
                     self._excl_fpath, self._gen_fpath,
                     self._tm_dset, self._gen_index,
